@@ -72,76 +72,6 @@ getNatDesignFromCoded <- function(x, a, b){
 }
 
 
-#' @title Return effects for each subgroup
-#'   
-#' @description  subgroups: returns the table the effects per groups.
-#' Code based on the \code{sbgroups} function written by Gilles Pujol for
-#' the function \code{\link[sensitivity]{sb}} in the \code{sensitivity} package.
-#'   
-#' @param x data
-#' 
-#' @return data frame with groupnames and effects
-#'
-#' @examples 
-#' \donttest{
-#' set.seed(2)
-#' # Interesting for larger n:
-#' n <- 2
-#' lower <- c(-0.1, rep(-10,n))
-#' upper <- c(0.1, rep(10,n))
-#' 
-#' # Model-based optimization
-#' res <- spot(,funSphere,
-#'              lower, upper, 
-#'              control=list(funEvals=30,
-#'                           optimizer = optimNLOPTR)) 
-#'                           
-#' # Use the surrogate model for prediction                                                     
-#' predictFunKriging <- function(x){
-#'       predict(object = res$modelFit, x)
-#'       }
-#'
-#' # Determine sensitivity 
-#' sens <- sequentialBifurcation(predictFunKriging,
-#'                               lower, upper,
-#'                               k=n+1, interaction = TRUE, verbosity = 0)
-#' 
-#' # Extract group information (variable effects) from sensitivity analysis                                                           
-#' ps <- subgroups(sens)
-#' colors <- RColorBrewer::brewer.pal(12, "Set3") 
-#' barplot(ps$effect, names.arg=ps$group, col= colors) 
-#' }
-#'         
-#' @export
-#' 
-subgroups <- function(x) {
-  ## sort the data on i
-  y <- x$y
-  y[rank(x$i)] <- y
-  if (! is.null(x$ym)) {
-    ym <- x$ym
-    ym[rank(x$i)] <- ym
-  }
-  i <- sort(x$i)
-  
-  ## groups
-  n <- length(i)
-  lower <- i[1 : (n - 1)] + 1
-  upper <- i[2 : n]
-  
-  ## effects
-  if (is.null(x$ym)) {
-    effect = diff(y)
-  } else {
-    effect = (diff(y) - diff(ym)) / 2
-  }
-  T <- data.frame(lower = lower, upper = upper, effect = effect)
-  groupnames <- paste(T[, 1], T[, 2], sep = "-")
-  groupnames[T[, 1] == T[, 2]] <- paste(T[T[, 1] == T[, 2], 1])
-  return(data.frame(group = groupnames, effect = T[, 3]))
-}
-
-
 
 #' @title Interface SANN to SPOT
 #' 
